#
# spec file for package pari
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See
# http://pari.math.u-bordeaux.fr/archives/pari-dev-1211/msg00006.html
# for details on the SO versioning.

Name:           pari
%define sover  6
%define lname   libpari-gmp-tls%sover
Version:        2.11.3
Release:        lp152.1.3
Summary:        Computer Algebra System for computations in Number Theory
License:        GPL-2.0-only
Group:          Productivity/Scientific/Math
URL:            https://pari.math.u-bordeaux.fr/
#Git-Clone:	https://pari.math.u-bordeaux.fr/git/pari.git
#Git-Web:	https://pari.math.u-bordeaux.fr/cgi-bin/gitweb.cgi
Source:         https://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%version.tar.gz
Source2:        https://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%version.tar.gz.asc
Patch1:         pari-nodate.diff
BuildRequires:  fltk-devel
BuildRequires:  gmp-devel
BuildRequires:  libX11-devel
BuildRequires:  readline-devel
BuildRequires:  xorg-x11-proto-devel

%description
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package gp
Summary:        Frontend to the PARI Computer Algebra System
Group:          Productivity/Scientific/Math

%description gp
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package -n %lname
Summary:        Computer Algebra System library for fast computations in Number Theory
# This is used by the data packages to avoid having a too-old version of libpari:
Group:          System/Libraries
Provides:       libpari-gmp = %version

%description -n %lname
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package devel
Summary:        Development files for the PARI CAS
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%prep
%setup -q
%patch -P 1 -p1

%build
./Configure --prefix="%_prefix" \
	--bindir="%_bindir" --includedir="%_includedir" \
	--libdir="%_libdir" \
	--sysdatadir="%_libdir" --datadir="%_datadir/%name" \
	--mt=pthread
make %{?_smp_mflags} all \
	CFLAGS="%optflags -fno-strict-aliasing" \
	STRIP=true

%install
%make_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files gp
%_bindir/*
%_datadir/%name
%_libdir/%name.cfg
%_mandir/man*/*

%files -n %lname
%if 0%{?sle_version} <= 150000 && !0%{?is_opensuse}
%dir %_licensedir
%endif
%license COPYING
%_libdir/libpari-gmp-tls.so.%version
%_libdir/libpari-gmp-tls.so.%sover

%files devel
%doc examples/
%doc CHANGES CHANGES-* NEW README
%_includedir/pari/
%_libdir/libpari.so

%changelog
* Thu Mar  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.11.3
  * Avoid division by zero in Flx_extresultant when one input is 0.
  * Fix crashes executing "ispower(27,2^60)",
    "issquare(non square t_FFELT, &x)",
    "polcompositum(x^2+x/3+1,x^2+x/3+1)",
    "polrootsreal(x+0.)", "qflllgram([2,2,3;4,5,6])",
    or printf("%%10.6f\n",2^-100).
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Enable pthreads [boo#1142714]
- Avoid duplicate shipping of documentation.
* Sun Jul 28 2019 Simon Puchert <simonpuchert@alice.de>
- Update to new upstream release 2.11.2
  * Fixed minpoly(Mod(1,t^2)) causing SIGSEGV.
  * Fixed segfault in ffinvmap(m) on bad input.
  * Fixed factormod(x^3+1,[y^2+1,2]) causing SIGSEGV.
  * Fixed incorrect use of graphcolors leading to a SIGSEGV.
  * Fixed [a,b]=a possibly leading to memory corruption.
  * Fixed a memory leak in cgetalloc when lg overflows.
  * Fixed a possible segfault in padicappr.
  * Fixed core() possibly destroying its input,
    if stored in a GP variable.
  * Fixed stack corruption in quad_disc.
  * Fixed an infinite loop and stack corruption in ellmoddegree.
- Drop the separate changelog as RPMLINT warns about it being a
  duplicate of the file CHANGES (which is already included).
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Prepare the KDE4/Qt4 removal in factory.
* Mon Dec 10 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.11.1
  * Fixed a heap buffer overflow
  * Fixed mfsplit(mf,,flag) could return uninitialized objects
    causing SIGSEGV
  * Fixed incgam(-1000.4,2) causing SIGSEGV
  * Fixed mfcoefs(mfDelta(),0) causing SIGSEGV
  * Fixed segfault in rnfidealup
* Fri Dec  7 2018 Todd R <toddrme2178@gmail.com>
- Use %%macro instead of %%{macro} wherever possible.
* Fri Dec  7 2018 Todd R <toddrme2178@gmail.com>
- Fix building on SLE 15
- Use %%license macro
* Wed Aug 29 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.11.0
  * fixed uninitialized memory reads in lgcdii and red_montgomery
  * fixed memory leaks on pari_close [s_dbginfo, s_frame,
    colormap/graphcolor
  * polcoeff is deprecated and renamed polcoef: it now only
    applies to scalars, polynomials, series and rational
    functions; no longer to vector/matrices or quadratic forms
    (use [] or "component")
  * libpari: rename polcoeff0 -> polcoef, polcoeff_i -> polcoef_i,
    truecoeff -> truecoef
* Sat Sep  9 2017 jengelh@inai.de
- Update to new upstream release 2.9.3
  * Expression "issquare(Mod(1,67)*x^4+Mod(14,67)*x^2+Mod(49,67))"
    and "polroots(t_POL whose coeffs vary by a factor > 2^100000)"
    had caused SIGSEGV
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 2.9.1
  * lfunartin was using too much stack
  * fflog in char 3 or 5 was slower than intended
  * modular algorithms could fail for very large input
* Tue Nov 29 2016 jengelh@inai.de
- Update to new upstream release 2.9.0
  * fixed nfisisom(x,x^0) causing a crash
  * fixed crash on BIB in ellpointtoz(t_PADIC)
  * fixed wrong result for nfroots(non-monic t_POL)
  * fixed division by zero on doing
  e=ellinit([1,-1,1,98,126],O(5^10)); ellpointtoz(e,[1,14])
  * fixed rare crash in bnfisprincipal
* Sun Jul 31 2016 jengelh@inai.de
- Update to new upstream release 2.7.6
  * fixed O(1)==O(x) returning 0
  * matsolve(a,b) and a^(-1) gave wrong results [or SEGV] when t_MAT
  a was not square and a,b "modular"; same for x^(-1)
  * fixed a memory leak in pari_close: sopath was not freed
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.7.5
  * forprime engine could skip (fast) sieve in favour of (slow)
  * corrected return values/exceptions of functions
* Thu Feb 26 2015 jengelh@inai.de
- Update to new upstream release 2.7.3
  * "??bnrL1" and "??ellL1" did not work anymore and were fixed
  * thue(f^e*g, ...), e even, (f,g)=1 missed solutions such that f<0
  * nfisincl(t_POL, t_POL) could lead to wrong negative results
  * ellcard over non-prime fields could return wrong results
  * weber(1+I) was missing its imaginary part
* Sun Oct 12 2014 jengelh@inai.de
- Update to new upstream release 2.7.2. Fixed were:
  * (gp -p N) or (primelimit=N in gprc_ for N >= 436273290 resulted
  in an incorrect primetable.
  * monomial(exact zero, d, v) returned an invalid t_POL / t_RFRAC
  * contfracpnqn(v, n) returned partial quotients p[-1]/q[-1] ...
  p[n-1]/q[n-1], instead of the documented p[0]/q[0] ... p[n]/q[n]
  * iferr() could crash if some component of the t_ERROR were clones
  * nffactor() could overflow the stack when default accuracy too low
  * obsolete use of E=[a1,a2,a3,a4,a6] in ellmul crashed
  * incorrect rounding in mulrr/divrr for one-word precision reals
  * multiif did not handle correctly return() in conditions
  * is_gener_Fp could return wrong results
  * Fq_sqrtn(t_INT,..,&zeta) could return a wrong root of 1
  * bnfinit: SEGV due to precision issues
  * zm_zc_mul only worked for square zm matrices
  * [gphelp] infinite loop when $COLUMNS too small
  * factoru(1) returned a t_MAT instead of the expected "matsmall"
  * when compatible = 3; series() used a random precision
  * isprime() could crash on large input
  * gphelp did not handle === correctly
* Wed Aug  6 2014 jengelh@inai.de
- Update to new upstream release 2.7.1
  * Q_pvalrem(t_FRAC) returned a wrong result
  * The "ellheegner" function was using too much memory in some cases
  * nfhilbert(K,x,y, P above 2) could give wrong results
  * nfpow_u didn't handle non-integral rational numbers
  * nfroots(, t_POL with leading coeff -1) could miss solutions
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 2.7.0
  * added new library functions FlxX_to_FlxC, FlxXV_to_FlxM, polx_FlxX,
  Flx_lead, RgV_to_RgM
* Wed Feb  5 2014 jengelh@inai.de
- Update to new upstream release 2.5.5
  * sin'(1) with default(compatible,3) caused a crash
  * add missing call to normalize() in lift(t_POL/t_SER)
  * galoisinit(x^3+x^2-2*x-1) led to uninitialized read
  * polred() could return non-squarefree polynomials
  * bnrdisc could return a wrong result if the modulus had more than
  2 prime divisors
  * FFT mulii relied on unspecified order of evaluation
  * local() could corrupt polynomial variable of the same name
- Add pari-nodate.diff
* Sun Jan  6 2013 jengelh@inai.de
- Restore original library filename after confirming with upstream
  (This change is transparent to all users)
* Thu Nov 29 2012 jengelh@inai.de
- Update to new upstream release 2.5.3
  * Fixed a bug whereby calling a GP function with a lot of omitted
  arguments could crash
  * idealramgroups() and idealfrobenius() did not accept a bnf
* Sun Feb 26 2012 scorot@free.fr
- fix build requirement to allow build on SLE-11
- recompress source file to bzip2 format to allow build on SLE-11
- add missing %%%%post and %%%%postun scriptlets
* Mon Sep 26 2011 jengelh@medozas.de
- Initial package (version 2.5.0) for build.opensuse.org
